{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "okteto.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "okteto.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "okteto.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
The default public URL of the web app
*/}}
{{- define "okteto.defaultpublic" -}}
{{- $subdomain := required "A valid .Values.subdomain is required" .Values.subdomain }}
{{- printf "%s.%s" "okteto" $subdomain }}
{{- end -}}

{{/*
Allow for overriding the public URL of the application, it defaults to okteto.SUBDOMAINS
*/}}
{{- define "okteto.public" -}}
{{- $name := include "okteto.defaultpublic" . }}
{{- default $name .Values.publicOverride -}}
{{- end -}}

{{/*
Returns the private IP of the service exposing okteto
*/}}
{{- define "okteto.ingressprivateip" -}}
{{- if (index .Values "nginx-ingress" "enabled") -}}
{{- if .Values.ingress.ip -}}
{{- .Values.ingress.ip -}}
{{- else -}}
{{- printf "$(%s_NGINX_INGRESS_CONTROLLER_SERVICE_HOST)" (regexReplaceAll "-" .Release.Name "_") | upper -}}
{{- end -}}
{{- else -}}
{{- required "If 'nginx-ingress' is not enabled you need to set the value of '.Values.ingress.ip'" .Values.ingress.ip -}}
{{- end -}}
{{- end -}}

{{/*
Returns the private IP of the service exposing buildkit
*/}}
{{- define "okteto.buildkitprivateip" -}}
{{- printf "$(%s_OKTETO_ENTERPRISE_BUILDKIT_SERVICE_HOST)" (regexReplaceAll "-" .Release.Name "_") | upper -}}
{{- end -}}

{{/*
Returns the wildcard domain form
*/}}
{{- define "okteto.wildcard" -}}
{{- printf "*.%s" .Values.subdomain -}}
{{- end -}}

{{/*
Returns the name of the mutation webhook
*/}}
{{- define "okteto.webhook" -}}
{{- $name := include "okteto.fullname" . }}
{{- printf "%s-mutation-webhook" $name -}}
{{- end -}}

{{/*
Returns the name of the dev cluster role
*/}}
{{- define "okteto.devclusterrole" -}}
{{- $name := include "okteto.fullname" . }}
{{- printf "%s-psp" $name -}}
{{- end -}}

{{- define "okteto.joinListWithComma" -}}
{{- $local := dict "first" true -}}
{{- range $k, $v := . -}}{{- if not $local.first -}},{{- end -}}{{- $v -}}{{- $_ := set $local "first" false -}}{{- end -}}
{{- end -}}

{{- define "okteto.joinQuickstartsWithComma" -}}
{{- $local := dict "first" true -}}
{{- range $k, $v := . -}}{{- if not $local.first -}},{{- end -}}{{- $v.name -}},{{- $v.url -}}{{- $_ := set $local "first" false -}}{{- end -}}
{{- end -}}

{{- define "okteto.dockerconfig" -}}
{{- printf "{ \"auths\": { " -}}
{{- $local := dict "first" true -}}
{{- range $name, $cred := . -}}
{{- if not $local.first -}}
{{- printf ", " -}}
{{- end -}}
{{- if $cred.token -}}
{{- printf "\"%s\": { \"auth\": \"%s\" }" $cred.url $cred.token -}}
{{- else -}}
{{- printf "\"%s\": { \"auth\": \"%s\" }" $cred.url (printf "%s:%s" $cred.user $cred.password | b64enc) -}}
{{- end -}}
{{- $_ := set $local "first" false -}}
{{- end -}}
{{- printf " } }" -}}
{{- end -}}

{{/*
Return the appropriate apiVersion for ingress.
*/}}
{{- define "okteto.ingress.apiVersion" -}}
{{- if semverCompare "<1.14-0" .Capabilities.KubeVersion.GitVersion -}}
{{- print "extensions/v1beta1" -}}
{{- else if (semverCompare "<1.19-0" .Capabilities.KubeVersion.GitVersion) -}}
{{- print "networking.k8s.io/v1beta1" -}}
{{- else -}}
{{- print "networking.k8s.io/v1" -}}
{{- end -}}
{{- end -}}

{{/*
Return the appropriate apiVersion for MutatingWebhookConfiguration.
*/}}
{{- define "okteto.mutatingWebhookConfiguration.apiVersion" -}}
{{- if semverCompare "<1.19-0" .Capabilities.KubeVersion.GitVersion -}}
{{- print "admissionregistration.k8s.io/v1beta1" -}}
{{- else -}}
{{- print "admissionregistration.k8s.io/v1" -}}
{{- end -}}
{{- end -}}

{{/*
Return the appropriate apiVersion for networkPolicies.
*/}}
{{- define "okteto.networkPolicies.apiVersion" -}}
{{- if semverCompare "<1.16-0" .Capabilities.KubeVersion.GitVersion -}}
{{- print "extensions/v1beta1" -}}
{{- else -}}
{{- print "networking.k8s.io/v1" -}}
{{- end -}}
{{- end -}}

{{/*
The default public URL of buildkit
*/}}
{{- define "okteto.buildkit" -}}
{{- printf "%s.%s" "buildkit" .Values.subdomain }}
{{- end -}}

{{- define "okteto.registry" -}}
{{- printf "%s.%s" "registry" .Values.subdomain }}
{{- end -}}

{{- define "okteto.privateEndpoints" -}}
{{- printf "%s.%s" "private-endpoints" .Values.subdomain }}
{{- end -}}

{{/*
  Returns true if a solver is configured
*/}}
{{- define "okteto.solverAvailable" -}}
{{- if not .Values.cloud.enabled }}
{{- print false }}
{{- else if .Values.cloud.provider.azure.enabled }}
{{- print true }}
{{- else if .Values.cloud.provider.aws.enabled }}
{{- print true }}
{{- else if .Values.cloud.provider.gcp.enabled }}
{{- print true }}
{{- else if .Values.cloud.provider.digitalocean.enabled }}
{{- print true }}
{{- else if .Values.cloud.provider.civo.enabled }}
{{- print true }}
{{- else if .Values.cloud.provider.byo.enabled }}
{{- print true }}
{{- else }}
{{- print false }}
{{- end -}}
{{- end -}}

{{- define "okteto.selfSignedIssuer" -}}
{{ printf "%s-selfsign" (include "okteto.fullname" .) }}
{{- end -}}

{{- define "okteto.rootCAIssuer" -}}
{{ printf "%s-ca" (include "okteto.fullname" .) }}
{{- end -}}

{{- define "okteto.rootCACertificate" -}}
{{ printf "%s-ca" (include "okteto.fullname" .) }}
{{- end -}}

{{- define "okteto.internalCertificate" -}}
{{ printf "%s-internal-tls" (include "okteto.fullname" .) }}
{{- end -}}

{{- define "okteto.installDaemonset" -}}
{{- if .Values.prepullImages.enabled }}
{{- print true }}
{{- else if .Values.overrideRegistryResolution.enabled }}
{{- print true }}
{{- else if .Values.overrideFileWatchers.enabled }}
{{- print true }}
{{- else if .Values.injectDevelopmentBinaries.enabled }}
{{- print true }}
{{- else if .Values.privateRegistry }}
{{- print true }}
{{- else }}
{{- print false }}
{{- end -}}
{{- end -}}